@@ -13,9 +13,9 @@ urlpatterns = patterns("",
 
 if getattr(settings, "DEV_SERVER", False):
     urlpatterns += patterns("",
-        ("^%s/(?P<path>.*)$" % settings.MEDIA_URL.strip("/"), 
-            "django.views.static.serve", {"document_root": settings.MEDIA_ROOT}),
-        ("^favicon.ico$", "django.views.static.serve", {"document_root": 
+        ("^%s/(?P<path>.*)$" % settings.MEDIA_URL.strip("/"),
+            "django.views.static.serve",
+                {"document_root": settings.MEDIA_ROOT}),
+        ("^favicon.ico$", "django.views.static.serve", {"document_root":
             settings.MEDIA_ROOT, "path": "img/favicon.ico"}),
     )
-
